import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GithubProviderConfig {
    /**
     * Authenticate without a token.
     *
     * When `anonymous`is true, the provider will not be able to access resourcesthat require authentication.
     *
     * @stability stable
     */
    readonly anonymous?: boolean;
    /**
     * The GitHub Base API URL.
     *
     * @stability stable
     */
    readonly baseUrl?: string;
    /**
     * @stability stable
     */
    readonly individual?: boolean;
    /**
     * Whether server should be accessed without verifying the TLS certificate.
     *
     * @stability stable
     */
    readonly insecure?: boolean;
    /**
     * The GitHub organization name to manage.
     *
     * If `individual` is false, `organization` is required.
     *
     * @stability stable
     */
    readonly organization?: string;
    /**
     * The OAuth token used to connect to GitHub.
     *
     * If `anonymous` is false, `token` is required.
     *
     * @stability stable
     */
    readonly token?: string;
    /**
     * Alias name.
     *
     * @stability stable
     */
    readonly alias?: string;
}
/**
 * @stability stable
 */
export declare class GithubProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: GithubProviderConfig);
    private _anonymous?;
    /**
     * @stability stable
     */
    get anonymous(): boolean | undefined;
    /**
     * @stability stable
     */
    set anonymous(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetAnonymous(): void;
    /**
     * @stability stable
     */
    get anonymousInput(): boolean | undefined;
    private _baseUrl?;
    /**
     * @stability stable
     */
    get baseUrl(): string | undefined;
    /**
     * @stability stable
     */
    set baseUrl(value: string | undefined);
    /**
     * @stability stable
     */
    resetBaseUrl(): void;
    /**
     * @stability stable
     */
    get baseUrlInput(): string | undefined;
    private _individual?;
    /**
     * @stability stable
     */
    get individual(): boolean | undefined;
    /**
     * @stability stable
     */
    set individual(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetIndividual(): void;
    /**
     * @stability stable
     */
    get individualInput(): boolean | undefined;
    private _insecure?;
    /**
     * @stability stable
     */
    get insecure(): boolean | undefined;
    /**
     * @stability stable
     */
    set insecure(value: boolean | undefined);
    /**
     * @stability stable
     */
    resetInsecure(): void;
    /**
     * @stability stable
     */
    get insecureInput(): boolean | undefined;
    private _organization?;
    /**
     * @stability stable
     */
    get organization(): string | undefined;
    /**
     * @stability stable
     */
    set organization(value: string | undefined);
    /**
     * @stability stable
     */
    resetOrganization(): void;
    /**
     * @stability stable
     */
    get organizationInput(): string | undefined;
    private _token?;
    /**
     * @stability stable
     */
    get token(): string | undefined;
    /**
     * @stability stable
     */
    set token(value: string | undefined);
    /**
     * @stability stable
     */
    resetToken(): void;
    /**
     * @stability stable
     */
    get tokenInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
