import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface RepositoryConfig extends cdktf.TerraformMetaArguments {
    /**
     * @stability stable
     */
    readonly allowMergeCommit?: boolean;
    /**
     * @stability stable
     */
    readonly allowRebaseMerge?: boolean;
    /**
     * @stability stable
     */
    readonly allowSquashMerge?: boolean;
    /**
     * @stability stable
     */
    readonly archived?: boolean;
    /**
     * @stability stable
     */
    readonly autoInit?: boolean;
    /**
     * Can only be set after initial repository creation, and only if the target branch exists.
     *
     * @stability stable
     */
    readonly defaultBranch?: string;
    /**
     * @stability stable
     */
    readonly deleteBranchOnMerge?: boolean;
    /**
     * @stability stable
     */
    readonly description?: string;
    /**
     * @stability stable
     */
    readonly gitignoreTemplate?: string;
    /**
     * @stability stable
     */
    readonly hasDownloads?: boolean;
    /**
     * @stability stable
     */
    readonly hasIssues?: boolean;
    /**
     * @stability stable
     */
    readonly hasProjects?: boolean;
    /**
     * @stability stable
     */
    readonly hasWiki?: boolean;
    /**
     * @stability stable
     */
    readonly homepageUrl?: string;
    /**
     * @stability stable
     */
    readonly isTemplate?: boolean;
    /**
     * @stability stable
     */
    readonly licenseTemplate?: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly private?: boolean;
    /**
     * @stability stable
     */
    readonly topics?: string[];
    /**
     * template block.
     *
     * @stability stable
     */
    readonly template?: RepositoryTemplate[];
}
/**
 * @stability stable
 */
export interface RepositoryTemplate {
    /**
     * @stability stable
     */
    readonly owner: string;
    /**
     * @stability stable
     */
    readonly repository: string;
}
/**
 * @stability stable
 */
export declare class Repository extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: RepositoryConfig);
    private _allowMergeCommit?;
    /**
     * @stability stable
     */
    get allowMergeCommit(): boolean;
    /**
     * @stability stable
     */
    set allowMergeCommit(value: boolean);
    /**
     * @stability stable
     */
    resetAllowMergeCommit(): void;
    /**
     * @stability stable
     */
    get allowMergeCommitInput(): boolean | undefined;
    private _allowRebaseMerge?;
    /**
     * @stability stable
     */
    get allowRebaseMerge(): boolean;
    /**
     * @stability stable
     */
    set allowRebaseMerge(value: boolean);
    /**
     * @stability stable
     */
    resetAllowRebaseMerge(): void;
    /**
     * @stability stable
     */
    get allowRebaseMergeInput(): boolean | undefined;
    private _allowSquashMerge?;
    /**
     * @stability stable
     */
    get allowSquashMerge(): boolean;
    /**
     * @stability stable
     */
    set allowSquashMerge(value: boolean);
    /**
     * @stability stable
     */
    resetAllowSquashMerge(): void;
    /**
     * @stability stable
     */
    get allowSquashMergeInput(): boolean | undefined;
    private _archived?;
    /**
     * @stability stable
     */
    get archived(): boolean;
    /**
     * @stability stable
     */
    set archived(value: boolean);
    /**
     * @stability stable
     */
    resetArchived(): void;
    /**
     * @stability stable
     */
    get archivedInput(): boolean | undefined;
    private _autoInit?;
    /**
     * @stability stable
     */
    get autoInit(): boolean;
    /**
     * @stability stable
     */
    set autoInit(value: boolean);
    /**
     * @stability stable
     */
    resetAutoInit(): void;
    /**
     * @stability stable
     */
    get autoInitInput(): boolean | undefined;
    private _defaultBranch?;
    /**
     * @stability stable
     */
    get defaultBranch(): string;
    /**
     * @stability stable
     */
    set defaultBranch(value: string);
    /**
     * @stability stable
     */
    resetDefaultBranch(): void;
    /**
     * @stability stable
     */
    get defaultBranchInput(): string | undefined;
    private _deleteBranchOnMerge?;
    /**
     * @stability stable
     */
    get deleteBranchOnMerge(): boolean;
    /**
     * @stability stable
     */
    set deleteBranchOnMerge(value: boolean);
    /**
     * @stability stable
     */
    resetDeleteBranchOnMerge(): void;
    /**
     * @stability stable
     */
    get deleteBranchOnMergeInput(): boolean | undefined;
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    /**
     * @stability stable
     */
    get etag(): string;
    /**
     * @stability stable
     */
    get fullName(): string;
    /**
     * @stability stable
     */
    get gitCloneUrl(): string;
    private _gitignoreTemplate?;
    /**
     * @stability stable
     */
    get gitignoreTemplate(): string;
    /**
     * @stability stable
     */
    set gitignoreTemplate(value: string);
    /**
     * @stability stable
     */
    resetGitignoreTemplate(): void;
    /**
     * @stability stable
     */
    get gitignoreTemplateInput(): string | undefined;
    private _hasDownloads?;
    /**
     * @stability stable
     */
    get hasDownloads(): boolean;
    /**
     * @stability stable
     */
    set hasDownloads(value: boolean);
    /**
     * @stability stable
     */
    resetHasDownloads(): void;
    /**
     * @stability stable
     */
    get hasDownloadsInput(): boolean | undefined;
    private _hasIssues?;
    /**
     * @stability stable
     */
    get hasIssues(): boolean;
    /**
     * @stability stable
     */
    set hasIssues(value: boolean);
    /**
     * @stability stable
     */
    resetHasIssues(): void;
    /**
     * @stability stable
     */
    get hasIssuesInput(): boolean | undefined;
    private _hasProjects?;
    /**
     * @stability stable
     */
    get hasProjects(): boolean;
    /**
     * @stability stable
     */
    set hasProjects(value: boolean);
    /**
     * @stability stable
     */
    resetHasProjects(): void;
    /**
     * @stability stable
     */
    get hasProjectsInput(): boolean | undefined;
    private _hasWiki?;
    /**
     * @stability stable
     */
    get hasWiki(): boolean;
    /**
     * @stability stable
     */
    set hasWiki(value: boolean);
    /**
     * @stability stable
     */
    resetHasWiki(): void;
    /**
     * @stability stable
     */
    get hasWikiInput(): boolean | undefined;
    private _homepageUrl?;
    /**
     * @stability stable
     */
    get homepageUrl(): string;
    /**
     * @stability stable
     */
    set homepageUrl(value: string);
    /**
     * @stability stable
     */
    resetHomepageUrl(): void;
    /**
     * @stability stable
     */
    get homepageUrlInput(): string | undefined;
    /**
     * @stability stable
     */
    get htmlUrl(): string;
    /**
     * @stability stable
     */
    get httpCloneUrl(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _isTemplate?;
    /**
     * @stability stable
     */
    get isTemplate(): boolean;
    /**
     * @stability stable
     */
    set isTemplate(value: boolean);
    /**
     * @stability stable
     */
    resetIsTemplate(): void;
    /**
     * @stability stable
     */
    get isTemplateInput(): boolean | undefined;
    private _licenseTemplate?;
    /**
     * @stability stable
     */
    get licenseTemplate(): string;
    /**
     * @stability stable
     */
    set licenseTemplate(value: string);
    /**
     * @stability stable
     */
    resetLicenseTemplate(): void;
    /**
     * @stability stable
     */
    get licenseTemplateInput(): string | undefined;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    /**
     * @stability stable
     */
    get nodeId(): string;
    private _private?;
    /**
     * @stability stable
     */
    get private(): boolean;
    /**
     * @stability stable
     */
    set private(value: boolean);
    /**
     * @stability stable
     */
    resetPrivate(): void;
    /**
     * @stability stable
     */
    get privateInput(): boolean | undefined;
    /**
     * @stability stable
     */
    get sshCloneUrl(): string;
    /**
     * @stability stable
     */
    get svnUrl(): string;
    private _topics?;
    /**
     * @stability stable
     */
    get topics(): string[];
    /**
     * @stability stable
     */
    set topics(value: string[]);
    /**
     * @stability stable
     */
    resetTopics(): void;
    /**
     * @stability stable
     */
    get topicsInput(): string[] | undefined;
    private _template?;
    /**
     * @stability stable
     */
    get template(): RepositoryTemplate[];
    /**
     * @stability stable
     */
    set template(value: RepositoryTemplate[]);
    /**
     * @stability stable
     */
    resetTemplate(): void;
    /**
     * @stability stable
     */
    get templateInput(): RepositoryTemplate[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
